Crate grrs_lazy
grrs_
lazy
0.2.0
All Items
Crate Items
Functions
Crate
grrs_
lazy
Functions

find_
matches
Given an iterator on strings and a pattern string to search, returns an iterator of all the strings which contain the pattern.